agentle.agents.whatsapp.providers.evolution.evolution\_api\_provider
====================================================================

.. automodule:: agentle.agents.whatsapp.providers.evolution.evolution_api_provider

   
   .. rubric:: Functions

   .. autosummary::
   
      override
      urljoin
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      DownloadedMedia
      EvolutionAPIConfig
      EvolutionAPIProvider
      InMemorySessionStore
      Mapping
      MutableMapping
      SessionManager
      WhatsAppAudioMessage
      WhatsAppContact
      WhatsAppDocumentMessage
      WhatsAppImageMessage
      WhatsAppMediaMessage
      WhatsAppMessageStatus
      WhatsAppProvider
      WhatsAppSession
      WhatsAppTextMessage
      WhatsAppVideoMessage
      WhatsAppWebhookPayload
      datetime
   
   .. rubric:: Exceptions

   .. autosummary::
   
      EvolutionAPIError
   